@@ -1,20 +1,6 @@
-# This Python file uses the following encoding: utf-8
-# This file is part of gnome-tweak-tool.
-#
 # Copyright (c) 2011 John Stowers
-#
-# gnome-tweak-tool is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# gnome-tweak-tool is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with gnome-tweak-tool.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0+
+# License-Filename: LICENSES/GPL-3.0
 
 import os.path
 import logging
@@ -117,6 +103,8 @@ class Window(Gtk.ApplicationWindow):
         left_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
 
         self.entry = Gtk.SearchEntry(placeholder_text=_("Search Tweaks…"))
+        if (Gtk.check_version(3, 22, 20) == None):
+            self.entry.set_input_hints(Gtk.InputHints.NO_EMOJI)
         self.entry.connect("search-changed", self._on_search)
 
         self.searchbar = Gtk.SearchBar()
